@@ -5,12 +5,13 @@ import platform
 import pep8
 
 from flake8 import __version__
+from flake8 import callbacks
 from flake8.reporter import multiprocessing, BaseQReport, QueueReport
 from flake8.util import OrderedSet, is_windows, is_using_stdin
 
-_flake8_noqa = re.compile(r'flake8[:=]\s*noqa', re.I).search
+_flake8_noqa = re.compile(r'\s*# flake8[:=]\s*noqa', re.I).search
 
-EXTRA_EXCLUDE = '.tox'
+EXTRA_EXCLUDE = ['.tox', '.eggs', '*.egg']
 
 
 def _register_extensions():
@@ -19,6 +20,7 @@ def _register_extensions():
     extensions.add(('pep8', pep8.__version__))
     parser_hooks = []
     options_hooks = []
+    ignored_hooks = []
     try:
         from pkg_resources import iter_entry_points
     except ImportError:
@@ -32,27 +34,16 @@ def _register_extensions():
                 parser_hooks.append(checker.add_options)
             if hasattr(checker, 'parse_options'):
                 options_hooks.append(checker.parse_options)
-    return extensions, parser_hooks, options_hooks
-
-
-def _install_hook_cb(option, option_str, value, parser):
-    # For now, there's no way to affect a change in how pep8 processes
-    # options. If no args are provided and there's no config file present,
-    # it will error out because no input was provided. To get around this,
-    # when we're using --install-hook, we'll say that there were arguments so
-    # we can actually attempt to install the hook.
-    # See: https://gitlab.com/pycqa/flake8/issues/2 and
-    # https://github.com/jcrocholl/pep8/blob/4c5bf00cb613be617c7f48d3b2b82a1c7b895ac1/pep8.py#L1912
-    # for more context.
-    parser.values.install_hook = True
-    parser.rargs.append('.')
+            if getattr(checker, 'off_by_default', False) is True:
+                ignored_hooks.append(entry.name)
+    return extensions, parser_hooks, options_hooks, ignored_hooks
 
 
 def get_parser():
     """This returns an instance of optparse.OptionParser with all the
     extensions registered and options set. This wraps ``pep8.get_parser``.
     """
-    (extensions, parser_hooks, options_hooks) = _register_extensions()
+    (extensions, parser_hooks, options_hooks, ignored) = _register_extensions()
     details = ', '.join(['%s: %s' % ext for ext in extensions])
     python_version = get_python_version()
     parser = pep8.get_parser('flake8', '%s (%s) %s' % (
@@ -65,10 +56,6 @@ def get_parser():
             pass
 
     if multiprocessing:
-        try:
-            auto = multiprocessing.cpu_count() or 1
-        except NotImplementedError:
-            auto = 1
         parser.config_options.append('jobs')
         parser.add_option('-j', '--jobs', type='string', default='auto',
                           help="number of jobs to run simultaneously, "
@@ -81,7 +68,13 @@ def get_parser():
     # See comment above regarding why this has to be a callback.
     parser.add_option('--install-hook', default=False, dest='install_hook',
                       help='Install the appropriate hook for this '
-                      'repository.', action='callback', callback=_install_hook_cb)
+                      'repository.', action='callback',
+                      callback=callbacks.install_vcs_hook)
+    parser.add_option('--output-file', default=None,
+                      help='Redirect report to a file.',
+                      type='string', nargs=1, action='callback',
+                      callback=callbacks.redirect_stdout)
+    parser.ignored_extensions = ignored
     return parser, options_hooks
 
 
@@ -93,19 +86,31 @@ class StyleGuide(pep8.StyleGuide):
             print('checking %s' % filename)
         fchecker = self.checker_class(
             filename, lines=lines, options=self.options)
-        # Any "# flake8: noqa" line?
+        # Any "flake8: noqa" comments to ignore the entire file?
         if any(_flake8_noqa(line) for line in fchecker.lines):
             return 0
         return fchecker.check_all(expected=expected, line_offset=line_offset)
 
 
+def _disable_extensions(parser, options):
+    ignored_extensions = set(getattr(parser, 'ignored_extensions', []))
+    # Remove any of the selected extensions from the extensions ignored by
+    # default.
+    ignored_extensions -= set(options.select)
+    # Whatever is left afterwards should be unioned with options.ignore and
+    # options.ignore should be updated with that.
+    options.ignore = tuple(ignored_extensions.union(options.ignore))
+
+
 def get_style_guide(**kwargs):
-    """Parse the options and configure the checker. This returns a sub-class 
+    """Parse the options and configure the checker. This returns a sub-class
     of ``pep8.StyleGuide``."""
     kwargs['parser'], options_hooks = get_parser()
     styleguide = StyleGuide(**kwargs)
     options = styleguide.options
 
+    _disable_extensions(kwargs['parser'], options)
+
     if options.exclude and not isinstance(options.exclude, list):
         options.exclude = pep8.normalize_paths(options.exclude)
     elif not options.exclude:
